@@ -20,8 +20,8 @@ from trac.resource import ResourceNotFound
 from trac.ticket.api import IMilestoneChangeListener
 from trac.ticket.model import Version
 
-revision = "$Rev: 12164 $"
-url = "$URL: http://svn.edgewall.org/repos/trac/tags/trac-1.0.2/sample-plugins/milestone_to_version.py $"
+revision = "$Rev: 13230 $"
+url = "$URL: https://svn.edgewall.org/repos/trac/branches/1.0-stable/sample-plugins/milestone_to_version.py $"
 
 
 class MilestoneToVersion(Component):
@@ -60,19 +60,19 @@ class MilestoneToVersion(Component):
                 version.time = milestone.completed
                 version.update()
                 self.log.info('Existing version "%s" updated with completion '
-                              'time from milestone "%s"' %
-                              (version.name, milestone.name))
+                              'time from milestone "%s"', version.name,
+                              milestone.name)
             else:
                 self.log.info('Version "%s" already exists.  No new version '
-                              'created from milestone "%s"' %
-                              (version.name, milestone.name))
+                              'created from milestone "%s"', version.name,
+                              milestone.name)
         except ResourceNotFound:
             version = Version(self.env)
             version.name = version_name
             version.time = milestone.completed
             version.insert()
             self.log.info('New version "%s" created from completed milstone '
-                          '"%s".' % (version.name, milestone.name))
+                          '"%s".', version.name, milestone.name)
 
     def milestone_deleted(self, milestone):
         pass
