@@ -16,7 +16,6 @@ from __future__ import with_statement
 from datetime import datetime, timedelta
 from StringIO import StringIO
 import tempfile
-import shutil
 import unittest
 
 import trac.tests.compat
@@ -32,7 +31,7 @@ from trac.ticket.roadmap import MilestoneModule
 from trac.ticket.api import (
     IMilestoneChangeListener, ITicketChangeListener, TicketSystem
 )
-from trac.util.datefmt import from_utimestamp, to_utimestamp, utc
+from trac.util.datefmt import datetime_now, from_utimestamp, to_utimestamp, utc
 
 
 class TestTicketChangeListener(core.Component):
@@ -224,7 +223,7 @@ class TicketTestCase(unittest.TestCase):
         ticket['keywords'] = 'kw1'
         ticket['milestone'] = 'milestone1'
         ticket.insert()
-        
+
         ticket['keywords'] = '  kw1'
         ticket['milestone'] = 'milestone2'
         ticket.save_changes()
@@ -711,7 +710,7 @@ class TicketCommentEditTestCase(TicketCommentTestCase):
         listener = TestTicketChangeListener_2(self.env)
         ticket = Ticket(self.env, self.id)
         ticket.modify_comment(cdate=self.t2, author='jack',
-                              comment='New Comment 2', when=datetime.now(utc))
+                              comment='New Comment 2', when=datetime_now(utc))
 
         self.assertEqual('comment_modified', listener.action)
         self.assertEqual(ticket, listener.ticket)
@@ -749,7 +748,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
         ticket = Ticket(self.env, self.id)
         self.assertEqual('a', ticket['keywords'])
         self.assertEqual('change4', ticket['foo'])
-        t = datetime.now(utc)
+        t = datetime_now(utc)
         ticket.delete_change(cnum=4, when=t)
         self.assertEqual('a, b', ticket['keywords'])
         self.assertEqual('change3', ticket['foo'])
@@ -768,7 +767,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
         del TicketSystem(self.env).custom_fields
         ticket = Ticket(self.env, self.id)
         #
-        t = datetime.now(utc)
+        t = datetime_now(utc)
         ticket.delete_change(cnum=4, when=t)
         self.assertEqual('a, b', ticket['keywords'])
         # 'foo' is no longer defined for the ticket
@@ -785,7 +784,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
         ticket = Ticket(self.env, self.id)
         self.assertEqual('a', ticket['keywords'])
         self.assertEqual('change4', ticket['foo'])
-        t = datetime.now(utc)
+        t = datetime_now(utc)
         ticket.delete_change(cdate=self.t4, when=t)
         self.assertEqual('a, b', ticket['keywords'])
         self.assertEqual('change3', ticket['foo'])
@@ -799,7 +798,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
             comment=dict(author='joe', old='4', new='Comment 4'),
             keywords=dict(author='joe', old='a, b', new='a'),
             foo=dict(author='joe', old='change3', new='change4'))
-        t = datetime.now(utc)
+        t = datetime_now(utc)
         ticket.delete_change(cnum=3, when=t)
         self.assertIsNone(ticket.get_change(cnum=3))
         self.assertEqual('a', ticket['keywords'])
@@ -815,7 +814,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
             comment=dict(author='joe', old='4', new='Comment 4'),
             keywords=dict(author='joe', old='a, b', new='a'),
             foo=dict(author='joe', old='change3', new='change4'))
-        t = datetime.now(utc)
+        t = datetime_now(utc)
         ticket.delete_change(cdate=self.t3, when=t)
         self.assertIsNone(ticket.get_change(cdate=self.t3))
         self.assertEqual('a', ticket['keywords'])
@@ -851,7 +850,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
         ticket.delete_change(4)
         ticket.delete_change(3)
         ticket.delete_change(2)
-        t = datetime.now(utc)
+        t = datetime_now(utc)
         ticket.delete_change(1, when=t)
         self.assertEqual(t, ticket.time_changed)
 
@@ -859,7 +858,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
         listener = TestTicketChangeListener_2(self.env)
         ticket = Ticket(self.env, self.id)
 
-        ticket.delete_change(cdate=self.t3, when=datetime.now(utc))
+        ticket.delete_change(cdate=self.t3, when=datetime_now(utc))
         self.assertEqual('change_deleted', listener.action)
         self.assertEqual(ticket, listener.ticket)
         self.assertEqual(self.t3, listener.cdate)
@@ -867,7 +866,7 @@ class TicketCommentDeleteTestCase(TicketCommentTestCase):
                               foo=('change2', 'change3')),
                          listener.changes)
 
-        ticket.delete_change(cnum=2, when=datetime.now(utc))
+        ticket.delete_change(cnum=2, when=datetime_now(utc))
         self.assertEqual('change_deleted', listener.action)
         self.assertEqual(ticket, listener.ticket)
         self.assertEqual(self.t2, listener.cdate)
@@ -952,8 +951,7 @@ class MilestoneTestCase(unittest.TestCase):
         self.updated_at = self.created_at + timedelta(seconds=1)
 
     def tearDown(self):
-        shutil.rmtree(self.env.path)
-        self.env.reset_db()
+        self.env.reset_db_and_disk()
 
     def _create_milestone(self, **values):
         milestone = Milestone(self.env)
@@ -1106,7 +1104,7 @@ class MilestoneTestCase(unittest.TestCase):
         milestone = Milestone(self.env)
         milestone.name = 'MilestoneWithAttachment'
         milestone.insert()
-        
+
         attachment = Attachment(self.env, 'milestone', milestone.name)
         attachment.insert('foo.txt', StringIO(), 0, 1)
 
